summaryrefslogtreecommitdiff
path: root/src/airport_gui.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/airport_gui.cpp')
-rw-r--r--src/airport_gui.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/airport_gui.cpp b/src/airport_gui.cpp
index d170b0cbb..8e436f1cb 100644
--- a/src/airport_gui.cpp
+++ b/src/airport_gui.cpp
@@ -161,7 +161,7 @@ static EventState AirportToolbarGlobalHotkeys(int hotkey)
{
if (_game_mode != GM_NORMAL || !CanBuildVehicleInfrastructure(VEH_AIRCRAFT)) return ES_NOT_HANDLED;
Window *w = ShowBuildAirToolbar();
- if (w == NULL) return ES_NOT_HANDLED;
+ if (w == nullptr) return ES_NOT_HANDLED;
return w->OnHotkey(hotkey);
}
@@ -198,11 +198,11 @@ static WindowDesc _air_toolbar_desc(
*
* If the terraform toolbar is linked to the toolbar, that window is also opened.
*
* @return newly opened airport toolbar, or NULL if the toolbar could not be opened.
*/
Window *ShowBuildAirToolbar()
{
- if (!Company::IsValidID(_local_company)) return NULL;
+ if (!Company::IsValidID(_local_company)) return nullptr;
DeleteWindowByClass(WC_BUILD_TOOLBAR);
return AllocateWindowDescFront<BuildAirToolbarWindow>(&_air_toolbar_desc, TRANSPORT_AIR);
@@ -198,11 +198,11 @@ static WindowDesc _air_toolbar_desc(
* If the terraform toolbar is linked to the toolbar, that window is also opened.
*
- * @return newly opened airport toolbar, or NULL if the toolbar could not be opened.
+ * @return newly opened airport toolbar, or nullptr if the toolbar could not be opened.
*/
Window *ShowBuildAirToolbar()